dbt

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 21, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DbtModelDetailsResponse

type DbtModelDetailsResponse struct {
	common.CommonResponse
	Data DbtModelItem `json:"data"`
}

type DbtModelDetailsService added in v0.8.0

type DbtModelDetailsService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

func (*DbtModelDetailsService) Do added in v0.8.0

func (*DbtModelDetailsService) ModelId added in v0.8.0

type DbtModelItem

type DbtModelItem struct {
	ID        string `json:"id"`
	ModelName string `json:"model_name"`
	Scheduled bool   `json:"scheduled"`
}

type DbtModelsListResponse

type DbtModelsListResponse struct {
	common.CommonResponse
	Data struct {
		Items      []DbtModelItem `json:"items"`
		NextCursor string         `json:"next_cursor"`
	} `json:"data"`
}

type DbtModelsListService added in v0.8.0

type DbtModelsListService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

func (*DbtModelsListService) Cursor added in v0.8.0

func (*DbtModelsListService) Do added in v0.8.0

func (*DbtModelsListService) Limit added in v0.8.0

func (*DbtModelsListService) ProjectId added in v0.8.0

func (s *DbtModelsListService) ProjectId(value string) *DbtModelsListService

type DbtProjectConfig

type DbtProjectConfig struct {
	// contains filtered or unexported fields
}

func (*DbtProjectConfig) FolderPath

func (dc *DbtProjectConfig) FolderPath(value string) *DbtProjectConfig

func (*DbtProjectConfig) GitBranch

func (dc *DbtProjectConfig) GitBranch(value string) *DbtProjectConfig

func (*DbtProjectConfig) GitRemoteUrl

func (dc *DbtProjectConfig) GitRemoteUrl(value string) *DbtProjectConfig

func (*DbtProjectConfig) Request

func (dc *DbtProjectConfig) Request() *dbtProjectConfigRequest

type DbtProjectConfigResponse

type DbtProjectConfigResponse struct {
	GitRemoteUrl string `json:"git_remote_url"`
	GitBranch    string `json:"git_branch"`
	FolderPath   string `json:"folder_path"`
}

type DbtProjectCreateService added in v0.8.0

type DbtProjectCreateService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

func (*DbtProjectCreateService) DbtVersion added in v0.8.0

func (*DbtProjectCreateService) DefaultSchema added in v0.8.0

func (s *DbtProjectCreateService) DefaultSchema(value string) *DbtProjectCreateService

func (*DbtProjectCreateService) Do added in v0.8.0

func (*DbtProjectCreateService) EnvironmentVars added in v0.8.0

func (s *DbtProjectCreateService) EnvironmentVars(value []string) *DbtProjectCreateService

func (*DbtProjectCreateService) GroupID added in v0.8.0

func (*DbtProjectCreateService) ProjectConfig added in v0.8.0

func (*DbtProjectCreateService) TargetName added in v0.8.0

func (*DbtProjectCreateService) Threads added in v0.8.0

func (*DbtProjectCreateService) Type added in v0.8.0

type DbtProjectDeleteService added in v0.8.0

type DbtProjectDeleteService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

ProjectDeleteService implements the Project Management, Delete a project API. Ref. https://fivetran.com/docs/rest-api/projects#deleteaproject

func (*DbtProjectDeleteService) DbtProjectID added in v0.8.0

func (s *DbtProjectDeleteService) DbtProjectID(value string) *DbtProjectDeleteService

func (*DbtProjectDeleteService) Do added in v0.8.0

type DbtProjectDetailsData

type DbtProjectDetailsData struct {
	DbtProjectItem
	DbtVersion      string                   `json:"dbt_version"`
	PublicKey       string                   `json:"public_key"`
	DefaultSchema   string                   `json:"default_schema"`
	TargetName      string                   `json:"target_name"`
	Threads         int                      `json:"threads"`
	EnvironmentVars []string                 `json:"environment_vars"`
	Type            string                   `json:"type"`
	ProjectConfig   DbtProjectConfigResponse `json:"project_config"`
	Status          string                   `json:"status"`
	Errors          []string                 `json:"errors"`
}

type DbtProjectDetailsResponse

type DbtProjectDetailsResponse struct {
	common.CommonResponse
	Data struct {
		DbtProjectDetailsData
	} `json:"data"`
}

type DbtProjectDetailsService added in v0.8.0

type DbtProjectDetailsService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

func (*DbtProjectDetailsService) DbtProjectID added in v0.8.0

func (*DbtProjectDetailsService) Do added in v0.8.0

type DbtProjectItem

type DbtProjectItem struct {
	ID          string `json:"id"`
	GroupId     string `json:"group_id"`
	CreatedAt   string `json:"created_at"`
	CreatedById string `json:"created_by_id"`
}

type DbtProjectModifyService added in v0.8.0

type DbtProjectModifyService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

func (*DbtProjectModifyService) DbtProjectID added in v0.8.0

func (s *DbtProjectModifyService) DbtProjectID(value string) *DbtProjectModifyService

func (*DbtProjectModifyService) DbtVersion added in v0.8.0

func (*DbtProjectModifyService) Do added in v0.8.0

func (*DbtProjectModifyService) EnvironmentVars added in v0.8.0

func (s *DbtProjectModifyService) EnvironmentVars(value []string) *DbtProjectModifyService

func (*DbtProjectModifyService) ProjectConfig added in v0.8.0

func (*DbtProjectModifyService) TargetName added in v0.8.0

func (*DbtProjectModifyService) Threads added in v0.8.0

type DbtProjectTestResponse added in v0.9.3

type DbtProjectTestResponse struct {
	Code string `json:"code"`
	Data struct {
		DbtProjectId string `json:"dbt_project_id"`
		SetupTests   []struct {
			Title   string `json:"title"`
			Status  string `json:"status"`
			Message string `json:"message"`
		} `json:"setup_tests"`
	} `json:"data"`
}

type DbtProjectTestService added in v0.9.4

type DbtProjectTestService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

DbtProjectTestService implements the Transformations for dbt Core Management, Test dbt Project. Ref. https://fivetran.com/docs/rest-api/transformations-for-dbt-core-management#request_4

func (*DbtProjectTestService) Do added in v0.9.4

func (*DbtProjectTestService) ProjectID added in v0.9.4

func (s *DbtProjectTestService) ProjectID(value string) *DbtProjectTestService

type DbtProjectsListResponse

type DbtProjectsListResponse struct {
	common.CommonResponse
	Data struct {
		Items      []DbtProjectItem `json:"items"`
		NextCursor string           `json:"next_cursor"`
	} `json:"data"`
}

type DbtProjectsListService added in v0.8.0

type DbtProjectsListService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

func (*DbtProjectsListService) Cursor added in v0.8.0

func (*DbtProjectsListService) Do added in v0.8.0

func (*DbtProjectsListService) Limit added in v0.8.0

type DbtTransformationCreateService added in v0.8.0

type DbtTransformationCreateService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

func (*DbtTransformationCreateService) DbtModelId added in v0.8.0

func (*DbtTransformationCreateService) Do added in v0.8.0

func (*DbtTransformationCreateService) Paused added in v0.8.0

func (*DbtTransformationCreateService) RunTests added in v0.8.0

func (*DbtTransformationCreateService) Schedule added in v0.8.0

type DbtTransformationDeleteService added in v0.8.0

type DbtTransformationDeleteService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

func (*DbtTransformationDeleteService) Do added in v0.8.0

func (*DbtTransformationDeleteService) TransformationId added in v0.8.0

type DbtTransformationDetailsService added in v0.8.0

type DbtTransformationDetailsService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

func (*DbtTransformationDetailsService) Do added in v0.8.0

func (*DbtTransformationDetailsService) TransformationId added in v0.8.0

type DbtTransformationModifyService added in v0.8.0

type DbtTransformationModifyService struct {
	httputils.HttpService
	// contains filtered or unexported fields
}

func (*DbtTransformationModifyService) DbtTransformationId added in v0.8.0

func (*DbtTransformationModifyService) Do added in v0.8.0

func (*DbtTransformationModifyService) Paused added in v0.8.0

func (*DbtTransformationModifyService) RunTests added in v0.8.0

func (*DbtTransformationModifyService) Schedule added in v0.8.0

type DbtTransformationResponse

type DbtTransformationResponse struct {
	Code    string `json:"code"`
	Message string `json:"message"`
	Data    struct {
		ID              string                            `json:"id"`
		Status          string                            `json:"status"`
		Schedule        DbtTransformationScheduleResponse `json:"schedule"`
		LastRun         string                            `json:"last_run"`
		OutputModelName string                            `json:"output_model_name"`
		DbtProjectId    string                            `json:"dbt_project_id"`
		DbtModelId      string                            `json:"dbt_model_id"`
		NextRun         string                            `json:"next_run"`
		CreatedAt       string                            `json:"created_at"`
		ModelIds        []string                          `json:"model_ids"`
		ConnectorIds    []string                          `json:"connector_ids"`
		RunTests        bool                              `json:"run_tests"`
		Paused          bool                              `json:"paused"`
	} `json:"data"`
}

type DbtTransformationSchedule

type DbtTransformationSchedule struct {
	// contains filtered or unexported fields
}

func (*DbtTransformationSchedule) DaysOfWeek

func (dbtTransformationSchedule *DbtTransformationSchedule) DaysOfWeek(value []string) *DbtTransformationSchedule

func (*DbtTransformationSchedule) Interval

func (dbtTransformationSchedule *DbtTransformationSchedule) Interval(value int) *DbtTransformationSchedule

func (*DbtTransformationSchedule) Request

func (dbtTransformationSchedule *DbtTransformationSchedule) Request() *dbtTransformationScheduleRequest

func (*DbtTransformationSchedule) ScheduleType

func (dbtTransformationSchedule *DbtTransformationSchedule) ScheduleType(value string) *DbtTransformationSchedule

func (*DbtTransformationSchedule) TimeOfDay

func (dbtTransformationSchedule *DbtTransformationSchedule) TimeOfDay(value string) *DbtTransformationSchedule

type DbtTransformationScheduleResponse

type DbtTransformationScheduleResponse struct {
	ScheduleType string   `json:"schedule_type"`
	DaysOfWeek   []string `json:"days_of_week"`
	Interval     int      `json:"interval"`
	TimeOfDay    string   `json:"time_of_day"`
}

Jump to