Documentation
¶
Index ¶
- type ProxyConnectionMembership
- type ProxyConnectionMembershipsListResponse
- type ProxyConnectionMembershipsListService
- func (s *ProxyConnectionMembershipsListService) Cursor(value string) *ProxyConnectionMembershipsListService
- func (s *ProxyConnectionMembershipsListService) Do(ctx context.Context) (ProxyConnectionMembershipsListResponse, error)
- func (s *ProxyConnectionMembershipsListService) Limit(value int) *ProxyConnectionMembershipsListService
- func (s *ProxyConnectionMembershipsListService) ProxyId(value string) *ProxyConnectionMembershipsListService
- type ProxyCreateData
- type ProxyCreateResponse
- type ProxyCreateService
- type ProxyData
- type ProxyDeleteService
- type ProxyDetailsResponse
- type ProxyDetailsService
- type ProxyListResponse
- type ProxyListService
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProxyConnectionMembership ¶
type ProxyConnectionMembership struct {
ConnectionId string `json:"connection_id"`
}
type ProxyConnectionMembershipsListResponse ¶
type ProxyConnectionMembershipsListResponse struct {
Code string `json:"code"`
Data struct {
Items []ProxyConnectionMembership `json:"items"`
NextCursor string `json:"next_cursor"`
} `json:"data"`
}
type ProxyConnectionMembershipsListService ¶
type ProxyConnectionMembershipsListService struct {
httputils.HttpService
// contains filtered or unexported fields
}
ProxyConnectionMembershipsListService implements the Proxy Agent Management, Return all connections attached to the proxy agent Ref. https://fivetran.com/docs/rest-api/proxy-management#returnallconnectionsattachedtotheproxyagent
func (*ProxyConnectionMembershipsListService) Cursor ¶
func (s *ProxyConnectionMembershipsListService) Cursor(value string) *ProxyConnectionMembershipsListService
func (*ProxyConnectionMembershipsListService) Do ¶
func (s *ProxyConnectionMembershipsListService) Do(ctx context.Context) (ProxyConnectionMembershipsListResponse, error)
func (*ProxyConnectionMembershipsListService) Limit ¶
func (s *ProxyConnectionMembershipsListService) Limit(value int) *ProxyConnectionMembershipsListService
func (*ProxyConnectionMembershipsListService) ProxyId ¶
func (s *ProxyConnectionMembershipsListService) ProxyId(value string) *ProxyConnectionMembershipsListService
type ProxyCreateData ¶
type ProxyCreateResponse ¶
type ProxyCreateResponse struct {
common.CommonResponse
Data ProxyCreateData `json:"data"`
}
type ProxyCreateService ¶
type ProxyCreateService struct {
httputils.HttpService
// contains filtered or unexported fields
}
ProxyCreateService implements the Proxy Agent Management, Create a Proxy Agent. Ref. https://fivetran.com/docs/rest-api/proxy-management#createaproxyagent
func (*ProxyCreateService) DisplayName ¶
func (s *ProxyCreateService) DisplayName(value string) *ProxyCreateService
func (*ProxyCreateService) Do ¶
func (s *ProxyCreateService) Do(ctx context.Context) (ProxyCreateResponse, error)
func (*ProxyCreateService) GroupRegion ¶ added in v0.8.6
func (s *ProxyCreateService) GroupRegion(value string) *ProxyCreateService
type ProxyDeleteService ¶
type ProxyDeleteService struct {
httputils.HttpService
// contains filtered or unexported fields
}
ProxyDeleteService implements the Proxy Agent Management, Delete a Proxy Agent. Ref. https://fivetran.com/docs/rest-api/proxy-management#deleteaproxyagent
func (*ProxyDeleteService) Do ¶
func (s *ProxyDeleteService) Do(ctx context.Context) (common.CommonResponse, error)
func (*ProxyDeleteService) ProxyId ¶
func (s *ProxyDeleteService) ProxyId(value string) *ProxyDeleteService
type ProxyDetailsResponse ¶
type ProxyDetailsService ¶
type ProxyDetailsService struct {
httputils.HttpService
// contains filtered or unexported fields
}
ProxyDetailsService implements the Proxy Agent Management, Retrieve Proxy Agent Details. Ref. https://fivetran.com/docs/rest-api/proxy-management#retrieveproxyagentdetails
func (*ProxyDetailsService) Do ¶
func (s *ProxyDetailsService) Do(ctx context.Context) (ProxyDetailsResponse, error)
func (*ProxyDetailsService) ProxyId ¶
func (s *ProxyDetailsService) ProxyId(value string) *ProxyDetailsService
type ProxyListResponse ¶
type ProxyListService ¶
type ProxyListService struct {
httputils.HttpService
// contains filtered or unexported fields
}
ProxyListService implements the Proxy Agent Management, retrieve List all Proxy Agents. Ref. https://fivetran.com/docs/rest-api/proxy-management#listallproxyagents
func (*ProxyListService) Cursor ¶
func (s *ProxyListService) Cursor(value string) *ProxyListService
func (*ProxyListService) Do ¶
func (s *ProxyListService) Do(ctx context.Context) (ProxyListResponse, error)
func (*ProxyListService) Limit ¶
func (s *ProxyListService) Limit(value int) *ProxyListService