Documentation
¶
Index ¶
- type DbtModelDetailsResponse
- type DbtModelDetailsService
- type DbtModelItem
- type DbtModelsListResponse
- type DbtModelsListService
- func (s *DbtModelsListService) Cursor(value string) *DbtModelsListService
- func (s *DbtModelsListService) Do(ctx context.Context) (DbtModelsListResponse, error)
- func (s *DbtModelsListService) Limit(value int) *DbtModelsListService
- func (s *DbtModelsListService) ProjectId(value string) *DbtModelsListService
- type DbtProjectConfig
- type DbtProjectConfigResponse
- type DbtProjectCreateService
- func (s *DbtProjectCreateService) DbtVersion(value string) *DbtProjectCreateService
- func (s *DbtProjectCreateService) DefaultSchema(value string) *DbtProjectCreateService
- func (s *DbtProjectCreateService) Do(ctx context.Context) (DbtProjectDetailsResponse, error)
- func (s *DbtProjectCreateService) EnvironmentVars(value []string) *DbtProjectCreateService
- func (s *DbtProjectCreateService) GroupID(value string) *DbtProjectCreateService
- func (s *DbtProjectCreateService) ProjectConfig(value *DbtProjectConfig) *DbtProjectCreateService
- func (s *DbtProjectCreateService) TargetName(value string) *DbtProjectCreateService
- func (s *DbtProjectCreateService) Threads(value int) *DbtProjectCreateService
- func (s *DbtProjectCreateService) Type(value string) *DbtProjectCreateService
- type DbtProjectDeleteService
- type DbtProjectDetailsData
- type DbtProjectDetailsResponse
- type DbtProjectDetailsService
- type DbtProjectItem
- type DbtProjectModifyService
- func (s *DbtProjectModifyService) DbtProjectID(value string) *DbtProjectModifyService
- func (s *DbtProjectModifyService) DbtVersion(value string) *DbtProjectModifyService
- func (s *DbtProjectModifyService) Do(ctx context.Context) (DbtProjectDetailsResponse, error)
- func (s *DbtProjectModifyService) EnvironmentVars(value []string) *DbtProjectModifyService
- func (s *DbtProjectModifyService) ProjectConfig(value *DbtProjectConfig) *DbtProjectModifyService
- func (s *DbtProjectModifyService) TargetName(value string) *DbtProjectModifyService
- func (s *DbtProjectModifyService) Threads(value int) *DbtProjectModifyService
- type DbtProjectTestResponse
- type DbtProjectTestService
- type DbtProjectsListResponse
- type DbtProjectsListService
- type DbtTransformationCreateService
- func (s *DbtTransformationCreateService) DbtModelId(value string) *DbtTransformationCreateService
- func (s *DbtTransformationCreateService) Do(ctx context.Context) (DbtTransformationResponse, error)
- func (s *DbtTransformationCreateService) Paused(value bool) *DbtTransformationCreateService
- func (s *DbtTransformationCreateService) RunTests(value bool) *DbtTransformationCreateService
- func (s *DbtTransformationCreateService) Schedule(value *DbtTransformationSchedule) *DbtTransformationCreateService
- type DbtTransformationDeleteService
- type DbtTransformationDetailsService
- type DbtTransformationModifyService
- func (s *DbtTransformationModifyService) DbtTransformationId(value string) *DbtTransformationModifyService
- func (s *DbtTransformationModifyService) Do(ctx context.Context) (DbtTransformationResponse, error)
- func (s *DbtTransformationModifyService) Paused(value bool) *DbtTransformationModifyService
- func (s *DbtTransformationModifyService) RunTests(value bool) *DbtTransformationModifyService
- func (s *DbtTransformationModifyService) Schedule(value *DbtTransformationSchedule) *DbtTransformationModifyService
- type DbtTransformationResponse
- type DbtTransformationSchedule
- func (dbtTransformationSchedule *DbtTransformationSchedule) DaysOfWeek(value []string) *DbtTransformationSchedule
- func (dbtTransformationSchedule *DbtTransformationSchedule) Interval(value int) *DbtTransformationSchedule
- func (dbtTransformationSchedule *DbtTransformationSchedule) Request() *dbtTransformationScheduleRequest
- func (dbtTransformationSchedule *DbtTransformationSchedule) ScheduleType(value string) *DbtTransformationSchedule
- func (dbtTransformationSchedule *DbtTransformationSchedule) TimeOfDay(value string) *DbtTransformationSchedule
- type DbtTransformationScheduleResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DbtModelDetailsResponse ¶
type DbtModelDetailsResponse struct {
common.CommonResponse
Data DbtModelItem `json:"data"`
}
type DbtModelDetailsService ¶ added in v0.8.0
type DbtModelDetailsService struct {
httputils.HttpService
// contains filtered or unexported fields
}
func (*DbtModelDetailsService) Do ¶ added in v0.8.0
func (s *DbtModelDetailsService) Do(ctx context.Context) (DbtModelDetailsResponse, error)
func (*DbtModelDetailsService) ModelId ¶ added in v0.8.0
func (s *DbtModelDetailsService) ModelId(value string) *DbtModelDetailsService
type DbtModelItem ¶
type DbtModelsListResponse ¶
type DbtModelsListResponse struct {
common.CommonResponse
Data struct {
Items []DbtModelItem `json:"items"`
NextCursor string `json:"next_cursor"`
} `json:"data"`
}
type DbtModelsListService ¶ added in v0.8.0
type DbtModelsListService struct {
httputils.HttpService
// contains filtered or unexported fields
}
func (*DbtModelsListService) Cursor ¶ added in v0.8.0
func (s *DbtModelsListService) Cursor(value string) *DbtModelsListService
func (*DbtModelsListService) Do ¶ added in v0.8.0
func (s *DbtModelsListService) Do(ctx context.Context) (DbtModelsListResponse, error)
func (*DbtModelsListService) Limit ¶ added in v0.8.0
func (s *DbtModelsListService) Limit(value int) *DbtModelsListService
func (*DbtModelsListService) ProjectId ¶ added in v0.8.0
func (s *DbtModelsListService) ProjectId(value string) *DbtModelsListService
type DbtProjectConfig ¶
type DbtProjectConfig struct {
// contains filtered or unexported fields
}
func (*DbtProjectConfig) FolderPath ¶
func (dc *DbtProjectConfig) FolderPath(value string) *DbtProjectConfig
func (*DbtProjectConfig) GitBranch ¶
func (dc *DbtProjectConfig) GitBranch(value string) *DbtProjectConfig
func (*DbtProjectConfig) GitRemoteUrl ¶
func (dc *DbtProjectConfig) GitRemoteUrl(value string) *DbtProjectConfig
func (*DbtProjectConfig) Request ¶
func (dc *DbtProjectConfig) Request() *dbtProjectConfigRequest
type DbtProjectCreateService ¶ added in v0.8.0
type DbtProjectCreateService struct {
httputils.HttpService
// contains filtered or unexported fields
}
func (*DbtProjectCreateService) DbtVersion ¶ added in v0.8.0
func (s *DbtProjectCreateService) DbtVersion(value string) *DbtProjectCreateService
func (*DbtProjectCreateService) DefaultSchema ¶ added in v0.8.0
func (s *DbtProjectCreateService) DefaultSchema(value string) *DbtProjectCreateService
func (*DbtProjectCreateService) Do ¶ added in v0.8.0
func (s *DbtProjectCreateService) Do(ctx context.Context) (DbtProjectDetailsResponse, error)
func (*DbtProjectCreateService) EnvironmentVars ¶ added in v0.8.0
func (s *DbtProjectCreateService) EnvironmentVars(value []string) *DbtProjectCreateService
func (*DbtProjectCreateService) GroupID ¶ added in v0.8.0
func (s *DbtProjectCreateService) GroupID(value string) *DbtProjectCreateService
func (*DbtProjectCreateService) ProjectConfig ¶ added in v0.8.0
func (s *DbtProjectCreateService) ProjectConfig(value *DbtProjectConfig) *DbtProjectCreateService
func (*DbtProjectCreateService) TargetName ¶ added in v0.8.0
func (s *DbtProjectCreateService) TargetName(value string) *DbtProjectCreateService
func (*DbtProjectCreateService) Threads ¶ added in v0.8.0
func (s *DbtProjectCreateService) Threads(value int) *DbtProjectCreateService
func (*DbtProjectCreateService) Type ¶ added in v0.8.0
func (s *DbtProjectCreateService) Type(value string) *DbtProjectCreateService
type DbtProjectDeleteService ¶ added in v0.8.0
type DbtProjectDeleteService struct {
httputils.HttpService
// contains filtered or unexported fields
}
ProjectDeleteService implements the Project Management, Delete a project API. Ref. https://fivetran.com/docs/rest-api/projects#deleteaproject
func (*DbtProjectDeleteService) DbtProjectID ¶ added in v0.8.0
func (s *DbtProjectDeleteService) DbtProjectID(value string) *DbtProjectDeleteService
func (*DbtProjectDeleteService) Do ¶ added in v0.8.0
func (s *DbtProjectDeleteService) Do(ctx context.Context) (common.CommonResponse, error)
type DbtProjectDetailsData ¶
type DbtProjectDetailsData struct {
DbtProjectItem
DbtVersion string `json:"dbt_version"`
PublicKey string `json:"public_key"`
DefaultSchema string `json:"default_schema"`
TargetName string `json:"target_name"`
Threads int `json:"threads"`
EnvironmentVars []string `json:"environment_vars"`
Type string `json:"type"`
ProjectConfig DbtProjectConfigResponse `json:"project_config"`
Status string `json:"status"`
Errors []string `json:"errors"`
}
type DbtProjectDetailsResponse ¶
type DbtProjectDetailsResponse struct {
common.CommonResponse
Data struct {
DbtProjectDetailsData
} `json:"data"`
}
type DbtProjectDetailsService ¶ added in v0.8.0
type DbtProjectDetailsService struct {
httputils.HttpService
// contains filtered or unexported fields
}
func (*DbtProjectDetailsService) DbtProjectID ¶ added in v0.8.0
func (s *DbtProjectDetailsService) DbtProjectID(value string) *DbtProjectDetailsService
func (*DbtProjectDetailsService) Do ¶ added in v0.8.0
func (s *DbtProjectDetailsService) Do(ctx context.Context) (DbtProjectDetailsResponse, error)
type DbtProjectItem ¶
type DbtProjectModifyService ¶ added in v0.8.0
type DbtProjectModifyService struct {
httputils.HttpService
// contains filtered or unexported fields
}
func (*DbtProjectModifyService) DbtProjectID ¶ added in v0.8.0
func (s *DbtProjectModifyService) DbtProjectID(value string) *DbtProjectModifyService
func (*DbtProjectModifyService) DbtVersion ¶ added in v0.8.0
func (s *DbtProjectModifyService) DbtVersion(value string) *DbtProjectModifyService
func (*DbtProjectModifyService) Do ¶ added in v0.8.0
func (s *DbtProjectModifyService) Do(ctx context.Context) (DbtProjectDetailsResponse, error)
func (*DbtProjectModifyService) EnvironmentVars ¶ added in v0.8.0
func (s *DbtProjectModifyService) EnvironmentVars(value []string) *DbtProjectModifyService
func (*DbtProjectModifyService) ProjectConfig ¶ added in v0.8.0
func (s *DbtProjectModifyService) ProjectConfig(value *DbtProjectConfig) *DbtProjectModifyService
func (*DbtProjectModifyService) TargetName ¶ added in v0.8.0
func (s *DbtProjectModifyService) TargetName(value string) *DbtProjectModifyService
func (*DbtProjectModifyService) Threads ¶ added in v0.8.0
func (s *DbtProjectModifyService) Threads(value int) *DbtProjectModifyService
type DbtProjectTestResponse ¶ added in v0.9.3
type DbtProjectTestService ¶ added in v0.9.4
type DbtProjectTestService struct {
httputils.HttpService
// contains filtered or unexported fields
}
DbtProjectTestService implements the Transformations for dbt Core Management, Test dbt Project. Ref. https://fivetran.com/docs/rest-api/transformations-for-dbt-core-management#request_4
func (*DbtProjectTestService) Do ¶ added in v0.9.4
func (s *DbtProjectTestService) Do(ctx context.Context) (DbtProjectTestResponse, error)
func (*DbtProjectTestService) ProjectID ¶ added in v0.9.4
func (s *DbtProjectTestService) ProjectID(value string) *DbtProjectTestService
type DbtProjectsListResponse ¶
type DbtProjectsListResponse struct {
common.CommonResponse
Data struct {
Items []DbtProjectItem `json:"items"`
NextCursor string `json:"next_cursor"`
} `json:"data"`
}
type DbtProjectsListService ¶ added in v0.8.0
type DbtProjectsListService struct {
httputils.HttpService
// contains filtered or unexported fields
}
func (*DbtProjectsListService) Cursor ¶ added in v0.8.0
func (s *DbtProjectsListService) Cursor(value string) *DbtProjectsListService
func (*DbtProjectsListService) Do ¶ added in v0.8.0
func (s *DbtProjectsListService) Do(ctx context.Context) (DbtProjectsListResponse, error)
func (*DbtProjectsListService) Limit ¶ added in v0.8.0
func (s *DbtProjectsListService) Limit(value int) *DbtProjectsListService
type DbtTransformationCreateService ¶ added in v0.8.0
type DbtTransformationCreateService struct {
httputils.HttpService
// contains filtered or unexported fields
}
func (*DbtTransformationCreateService) DbtModelId ¶ added in v0.8.0
func (s *DbtTransformationCreateService) DbtModelId(value string) *DbtTransformationCreateService
func (*DbtTransformationCreateService) Do ¶ added in v0.8.0
func (s *DbtTransformationCreateService) Do(ctx context.Context) (DbtTransformationResponse, error)
func (*DbtTransformationCreateService) Paused ¶ added in v0.8.0
func (s *DbtTransformationCreateService) Paused(value bool) *DbtTransformationCreateService
func (*DbtTransformationCreateService) RunTests ¶ added in v0.8.0
func (s *DbtTransformationCreateService) RunTests(value bool) *DbtTransformationCreateService
func (*DbtTransformationCreateService) Schedule ¶ added in v0.8.0
func (s *DbtTransformationCreateService) Schedule(value *DbtTransformationSchedule) *DbtTransformationCreateService
type DbtTransformationDeleteService ¶ added in v0.8.0
type DbtTransformationDeleteService struct {
httputils.HttpService
// contains filtered or unexported fields
}
func (*DbtTransformationDeleteService) Do ¶ added in v0.8.0
func (s *DbtTransformationDeleteService) Do(ctx context.Context) (common.CommonResponse, error)
func (*DbtTransformationDeleteService) TransformationId ¶ added in v0.8.0
func (s *DbtTransformationDeleteService) TransformationId(value string) *DbtTransformationDeleteService
type DbtTransformationDetailsService ¶ added in v0.8.0
type DbtTransformationDetailsService struct {
httputils.HttpService
// contains filtered or unexported fields
}
func (*DbtTransformationDetailsService) Do ¶ added in v0.8.0
func (s *DbtTransformationDetailsService) Do(ctx context.Context) (DbtTransformationResponse, error)
func (*DbtTransformationDetailsService) TransformationId ¶ added in v0.8.0
func (s *DbtTransformationDetailsService) TransformationId(value string) *DbtTransformationDetailsService
type DbtTransformationModifyService ¶ added in v0.8.0
type DbtTransformationModifyService struct {
httputils.HttpService
// contains filtered or unexported fields
}
func (*DbtTransformationModifyService) DbtTransformationId ¶ added in v0.8.0
func (s *DbtTransformationModifyService) DbtTransformationId(value string) *DbtTransformationModifyService
func (*DbtTransformationModifyService) Do ¶ added in v0.8.0
func (s *DbtTransformationModifyService) Do(ctx context.Context) (DbtTransformationResponse, error)
func (*DbtTransformationModifyService) Paused ¶ added in v0.8.0
func (s *DbtTransformationModifyService) Paused(value bool) *DbtTransformationModifyService
func (*DbtTransformationModifyService) RunTests ¶ added in v0.8.0
func (s *DbtTransformationModifyService) RunTests(value bool) *DbtTransformationModifyService
func (*DbtTransformationModifyService) Schedule ¶ added in v0.8.0
func (s *DbtTransformationModifyService) Schedule(value *DbtTransformationSchedule) *DbtTransformationModifyService
type DbtTransformationResponse ¶
type DbtTransformationResponse struct {
Code string `json:"code"`
Message string `json:"message"`
Data struct {
ID string `json:"id"`
Status string `json:"status"`
Schedule DbtTransformationScheduleResponse `json:"schedule"`
LastRun string `json:"last_run"`
OutputModelName string `json:"output_model_name"`
DbtProjectId string `json:"dbt_project_id"`
DbtModelId string `json:"dbt_model_id"`
NextRun string `json:"next_run"`
CreatedAt string `json:"created_at"`
ModelIds []string `json:"model_ids"`
ConnectorIds []string `json:"connector_ids"`
RunTests bool `json:"run_tests"`
Paused bool `json:"paused"`
} `json:"data"`
}
type DbtTransformationSchedule ¶
type DbtTransformationSchedule struct {
// contains filtered or unexported fields
}
func (*DbtTransformationSchedule) DaysOfWeek ¶
func (dbtTransformationSchedule *DbtTransformationSchedule) DaysOfWeek(value []string) *DbtTransformationSchedule
func (*DbtTransformationSchedule) Interval ¶
func (dbtTransformationSchedule *DbtTransformationSchedule) Interval(value int) *DbtTransformationSchedule
func (*DbtTransformationSchedule) Request ¶
func (dbtTransformationSchedule *DbtTransformationSchedule) Request() *dbtTransformationScheduleRequest
func (*DbtTransformationSchedule) ScheduleType ¶
func (dbtTransformationSchedule *DbtTransformationSchedule) ScheduleType(value string) *DbtTransformationSchedule
func (*DbtTransformationSchedule) TimeOfDay ¶
func (dbtTransformationSchedule *DbtTransformationSchedule) TimeOfDay(value string) *DbtTransformationSchedule
Source Files
¶
- common_types.go
- dbt_model_details.go
- dbt_models_list.go
- dbt_project_config.go
- dbt_project_create.go
- dbt_project_delete.go
- dbt_project_details.go
- dbt_project_modify.go
- dbt_project_tests.go
- dbt_projects_list.go
- dbt_transformation_create.go
- dbt_transformation_delete.go
- dbt_transformation_details.go
- dbt_transformation_modify.go
- dbt_transformation_schedule.go
Click to show internal directories.
Click to hide internal directories.